import pandas as pd
import os
import argparse
import sys

_FOGLAMP_ROOT = os.getenv("FOGLAMP_ROOT", default='/usr/local/foglamp')
if not os.path.exists(_FOGLAMP_ROOT):
    print('Make sure FOGLAMP_ROOT exist')
    sys.exit(1)

_FOGLAMP_DATA = os.path.expanduser(_FOGLAMP_ROOT + '/data')

"""
Usage 
python3 process_csv_data.py --input_file_name vibe-2019-12-12.csv --output_file_name vibration.csv --chunksize 10000
"""

ap = argparse.ArgumentParser()
ap.add_argument("-i", "--input_file_name", required=True,
                help="Name of input_file")
ap.add_argument("-o", "--output_file_name", required=True,
                help="File name of processed file")
ap.add_argument("-c", "--chunksize", type=int, default=10000,
                help="Chunk size")

args = vars(ap.parse_args())

out_file_name = args['output_file_name']
in_file_name = args['input_file_name']
csv_out_path = '{}/{}'.format(_FOGLAMP_DATA, out_file_name)
csv_in_path = '{}/{}'.format(_FOGLAMP_DATA, in_file_name)

if not os.path.exists(csv_in_path):
    print('The input file does not exist')
    sys.exit(1)

if os.path.exists(csv_out_path):
    print('The converted file already exists change the output file name or delete the earlier converted file.')
    sys.exit(1)

chunksize = args['chunksize']


def get_clean_csv_file(csv_in_path, csv_out_path, chunksize=10000):
    """
    Converts a raw csv file of format like "{""channel1"":0.0083912037,""channel2"":0.0071383551}"
    to a format like    channel1,    channel2
                        0.0083912037,0.0071383551
    Args:
        csv_in_path: Name of input_file (Full path)
        csv_out_path: Full File path of processed file (will be stored in same directory as input file)
        chunksize: The chunk size required to process the csv file

    Returns: None

    """
    df_iter = pd.read_csv(csv_in_path, chunksize=chunksize, iterator=True)
    i = 0
    while True:
        try:
            if i == 0:
                df = next(df_iter)
                df['channel1'] = df['reading'].apply(lambda x: x.split(",")[0].split(":")[1])
                df['channel2'] = df['reading'].apply(lambda x: x.split(",")[1].split(":")[1].split("}")[0])
                df[['channel1', 'channel2', 'user_ts']].to_csv(csv_out_path, mode='a', index=False)
            else:
                df = next(df_iter)
                df['channel1'] = df['reading'].apply(lambda x: x.split(",")[0].split(":")[1])
                df['channel2'] = df['reading'].apply(lambda x: x.split(",")[1].split(":")[1].split("}")[0])
                df[['channel1', 'channel2', 'user_ts']].to_csv(csv_out_path, mode='a', index=False, header=None)
            i += 1
        except StopIteration:
            break


get_clean_csv_file(csv_in_path, csv_out_path, chunksize)
